# ALMA Data Reduction Script

# Calibration

thesteps = []
step_title = {0: 'Import of the ASDM',
              1: 'Fix of SYSCAL table times',
              2: 'listobs',
              3: 'A priori flagging',
              4: 'Generation and time averaging of the WVR cal table',
              5: 'Generation of the Tsys cal table',
              6: 'Generation of the antenna position cal table',
              7: 'Application of the WVR, Tsys and antpos cal tables',
              8: 'Split out science SPWs and time average',
              9: 'Listobs, clear pointing table, and save original flags',
              10: 'Initial flagging',
              11: 'Putting a model for the flux calibrator(s)',
              12: 'Save flags before bandpass cal',
              13: 'Bandpass calibration',
              14: 'Save flags before gain cal',
              15: 'Gain calibration',
              16: 'Save flags before applycal',
              17: 'Application of the bandpass and gain cal tables',
              18: 'Split out corrected column'}

if 'applyonly' not in globals(): applyonly = False
try:
  print 'List of steps to be executed ...', mysteps
  thesteps = mysteps
except:
  print 'global variable mysteps not set.'
if (thesteps==[]):
  thesteps = range(0,len(step_title))
  print 'Executing all steps: ', thesteps

# The Python variable 'mysteps' will control which steps
# are executed when you start the script using
#   execfile('scriptForCalibration.py')
# e.g. setting
#   mysteps = [2,3,4]# before starting the script will make the script execute
# only steps 2, 3, and 4
# Setting mysteps = [] will make it execute all steps.

import re

import os

if applyonly != True: es = aU.stuffForScienceDataReduction() 


if re.search('^4.2.2', casadef.casa_version) == None:
 sys.exit('ERROR: PLEASE USE THE SAME VERSION OF CASA THAT YOU USED FOR GENERATING THE SCRIPT: 4.2.2')


# CALIBRATE_AMPLI: J0510+1800
# CALIBRATE_ATMOSPHERE: HL Tau,J0431+2037,J0510+1800
# CALIBRATE_BANDPASS: J0510+1800
# CALIBRATE_FLUX: J0510+1800
# CALIBRATE_FOCUS: 
# CALIBRATE_PHASE: J0431+2037
# CALIBRATE_POINTING: J0510+1800
# OBSERVE_TARGET: HL Tau

# Using reference antenna = DA51

# Import of the ASDM
mystep = 0
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  if os.path.exists('uid___A002_X91a416_X3b2.ms') == False:
    importasdm('uid___A002_X91a416_X3b2', asis='Antenna Station Receiver Source CalAtmosphere CalWVR')
  if applyonly != True: es.fixForCSV2555('uid___A002_X91a416_X3b2.ms')

# Fix of SYSCAL table times
mystep = 1
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  from recipes.almahelpers import fixsyscaltimes
  fixsyscaltimes(vis = 'uid___A002_X91a416_X3b2.ms')

print "# A priori calibration"

# listobs
mystep = 2
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf uid___A002_X91a416_X3b2.ms.listobs')
  listobs(vis = 'uid___A002_X91a416_X3b2.ms',
    listfile = 'uid___A002_X91a416_X3b2.ms.listobs')
  
  

# A priori flagging
mystep = 3
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  flagdata(vis = 'uid___A002_X91a416_X3b2.ms',
    mode = 'manual',
    spw = '1~22',
    autocorr = T,
    flagbackup = F)
  
  flagdata(vis = 'uid___A002_X91a416_X3b2.ms',
    mode = 'manual',
    intent = '*POINTING*,*ATMOSPHERE*',
    flagbackup = F)
  
  flagcmd(vis = 'uid___A002_X91a416_X3b2.ms',
    inpmode = 'table',
    useapplied = True,
    action = 'plot',
    plotfile = 'uid___A002_X91a416_X3b2.ms.flagcmd.png')
  
  flagcmd(vis = 'uid___A002_X91a416_X3b2.ms',
    inpmode = 'table',
    savepars = True,outfile='uid___A002_X91a416_X3b2.ms.flags.txt',
    useapplied = True,
    action = 'apply')
  

# Generation and time averaging of the WVR cal table
mystep = 4
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf uid___A002_X91a416_X3b2.ms.wvr') 
  
  os.system('rm -rf uid___A002_X91a416_X3b2.ms.wvrgcal') 
  
  mylogfile = casalog.logfile()
  casalog.setlogfile('uid___A002_X91a416_X3b2.ms.wvrgcal')
  
  wvrgcal(vis = 'uid___A002_X91a416_X3b2.ms',
    caltable = 'uid___A002_X91a416_X3b2.ms.wvr',
    toffset = 0,
    tie = ['HL Tau,J0431+2037'],
    statsource = 'HL Tau')
  
  casalog.setlogfile(mylogfile)
  
  # This is a temporary workaround, which will be included in a future version of CASA
  
  tb.open('uid___A002_X91a416_X3b2.ms.wvr', nomodify=False)
  count = 0
  numrows = tb.nrows()
  mycparamcol = tb.getcol('CPARAM')
  for i in range(0, numrows):
      if mycparamcol[0][0][i] == (1.+0.j):
          tb.putcell('FLAG', i, [[True]])
          count += 1
  tb.close()
  del mycparamcol
  if(numrows>0):
      print 'Flagged', count, 'of', numrows, 'solutions =', 100.*count/float(numrows),'%'
  
  
  os.system('rm -rf uid___A002_X91a416_X3b2.ms.wvr.smooth') 
  
  smoothcal(vis = 'uid___A002_X91a416_X3b2.ms',
    tablein = 'uid___A002_X91a416_X3b2.ms.wvr',
    caltable = 'uid___A002_X91a416_X3b2.ms.wvr.smooth',
    smoothtype = 'mean',
    smoothtime = 6.048)
  
  
  if applyonly != True: aU.plotWVRSolutions(caltable='uid___A002_X91a416_X3b2.ms.wvr.smooth', spw='13', antenna='DA51',
    yrange=[-199,199],subplot=22, interactive=False,
    figfile='uid___A002_X91a416_X3b2.ms.wvr.smooth.plots/uid___A002_X91a416_X3b2.ms.wvr.smooth') 
  
  #Note: If you see wraps in these plots, try changing yrange or unwrap=True 
  #Note: If all plots look strange, it may be a bad WVR on the reference antenna.
  #      To check, you can set antenna='' to show all baselines.
  

# Generation of the Tsys cal table
mystep = 5
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf uid___A002_X91a416_X3b2.ms.tsys') 
  gencal(vis = 'uid___A002_X91a416_X3b2.ms',
    caltable = 'uid___A002_X91a416_X3b2.ms.tsys',
    caltype = 'tsys')
  flagdata('uid___A002_X91a416_X3b2.ms.tsys',mode='manual',flagbackup=F,
           spw='9:0~3;124~127,11:0~3;124~127,13:0~3,124~127,15:0~3,124~127')
  if applyonly != True: aU.plotbandpass(caltable='uid___A002_X91a416_X3b2.ms.tsys', overlay='time', 
    xaxis='freq', yaxis='amp', subplot=22, buildpdf=False, interactive=False,
    showatm=True,pwv='auto',chanrange='5~123',showfdm=True, 
    field='', figfile='uid___A002_X91a416_X3b2.ms.tsys.plots.overlayTime/uid___A002_X91a416_X3b2.ms.tsys') 
  
  
  if applyonly != True: es.checkCalTable('uid___A002_X91a416_X3b2.ms.tsys', msName='uid___A002_X91a416_X3b2.ms', interactive=False) 
  

# Generation of the antenna position cal table
mystep = 6
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]
  
  os.system('rm -rf uid___A002_X91a416_X3b2.ms.antpos') 
  gencal(vis = 'uid___A002_X91a416_X3b2.ms',
    caltable = 'uid___A002_X91a416_X3b2.ms.antpos',
    caltype = 'antpos',
    parameter = [-0.0017382, +0.002224, +0.000802, # DA41 on S301 change=2.935mm
                 +0.0010010, -0.002643, -0.000459, # DA42 on A006 change=2.863mm
                 -0.0020990, +0.002281, +0.000397, # DA43 on S306 change=3.125mm
                 -0.0002283, +0.000688, +0.000188, # DA45 on A127 change=0.749mm
                 -0.0013670, +0.001688, -0.000025, # DA46 on A058 change=2.172mm
                 +0.0003610, -0.000860, -0.000305, # DA48 on W207 change=0.981mm
                 -0.0002937, +0.000536, +0.000205, # DA49 on A029 change=0.645mm
                 +0.0013120, -0.002341, -0.000482, # DA50 on W204 change=2.727mm
                 -0.0003235, +0.000310, -0.000253, # DA51 on A082 change=0.515mm
                 -0.0001640, -0.000059, +0.000255, # DA52 on A035 change=0.309mm
                 -0.0006170, -0.000772, -0.002025, # DA55 on S309 change=2.253mm
                 -0.0012060, +0.001494, +0.000602, # DA56 on A131 change=2.012mm
                 -0.0006330, +0.000739, +0.000357, # DA57 on A076 change=1.037mm
                 +0.0015283, -0.004478, -0.003326, # DA58 on A001 change=5.783mm
                 -0.0019700, +0.002534, +0.000251, # DA60 on P404 change=3.219mm
                 -0.0002500, +0.000522, +0.000186, # DA61 on A075 change=0.607mm
                 +0.0008350, -0.001575, -0.000489, # DA62 on W206 change=1.849mm
                 -0.0004555, +0.001180, +0.000210, # DA63 on A132 change=1.282mm
                 -0.0023837, +0.002720, +0.000299, # DA64 on P402 change=3.629mm
                 -0.0005062, +0.000614, +0.000190, # DV01 on A072 change=0.818mm
                 -0.0015335, +0.001681, -0.000106, # DV04 on A078 change=2.278mm
                 +0.0002210, -0.001266, +0.000329, # DV07 on W201 change=1.327mm
                 -0.0012494, +0.000979, +0.000365, # DV08 on A133 change=1.629mm
                 -0.0008851, +0.001659, +0.000376, # DV09 on A124 change=1.918mm
                 -0.0004107, +0.000539, +0.000109, # DV10 on A024 change=0.687mm
                 -0.0009172, +0.001557, +0.000406, # DV11 on A121 change=1.852mm
                 -0.0004596, +0.000429, +0.000536, # DV12 on A113 change=0.826mm
                 -0.0017830, +0.000726, -0.001078, # DV13 on S303 change=2.206mm
                 -0.0003510, +0.001720, -0.000659, # DV14 on P405 change=1.875mm
                 -0.0019810, +0.002374, +0.000330, # DV15 on A118 change=3.110mm
                 +0.0005096, +0.000044, -0.000411, # DV17 on W210 change=0.656mm
                 -0.0018450, +0.003876, +0.000473, # DV19 on P410 change=4.319mm
                 +0.0037129, +0.002571, +0.001168, # DV21 on A004 change=4.665mm
                 -0.0001749, +0.000694, +0.000152], # PM03 on T701 change=0.732mm
    antenna = 'DA41,DA42,DA43,DA45,DA46,DA48,DA49,DA50,DA51,DA52,DA55,DA56,DA57,DA58,DA60,DA61,DA62,DA63,DA64,DV01,DV04,DV07,DV08,DV09,DV10,DV11,DV12,DV13,DV14,DV15,DV17,DV19,DV21,PM03')


# Application of the WVR, Tsys and antpos cal tables
mystep = 7
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  
  
  from recipes.almahelpers import tsysspwmap
  tsysmap = tsysspwmap(vis = 'uid___A002_X91a416_X3b2.ms', tsystable = 'uid___A002_X91a416_X3b2.ms.tsys', tsysChanTol = 1)
  
  
  
  applycal(vis = 'uid___A002_X91a416_X3b2.ms',
    field = '0',
    spw = '13,15,17,19',
    gaintable = ['uid___A002_X91a416_X3b2.ms.tsys', 'uid___A002_X91a416_X3b2.ms.wvr.smooth', 'uid___A002_X91a416_X3b2.ms.antpos'],
    gainfield = ['0', '', ''],
    interp = 'linear,linear',
    spwmap = [tsysmap,[],[]],
    calwt = T,
    flagbackup = F)
  
  
  
  applycal(vis = 'uid___A002_X91a416_X3b2.ms',
    field = '1',
    spw = '13,15,17,19',
    gaintable = ['uid___A002_X91a416_X3b2.ms.tsys', 'uid___A002_X91a416_X3b2.ms.wvr.smooth', 'uid___A002_X91a416_X3b2.ms.antpos'],
    gainfield = ['1', '', ''],
    interp = 'linear,linear',
    spwmap = [tsysmap,[],[]],
    calwt = T,
    flagbackup = F)
  
  
  
  applycal(vis = 'uid___A002_X91a416_X3b2.ms',
    field = '2',
    spw = '13,15,17,19',
    gaintable = ['uid___A002_X91a416_X3b2.ms.tsys', 'uid___A002_X91a416_X3b2.ms.wvr.smooth', 'uid___A002_X91a416_X3b2.ms.antpos'],
    gainfield = ['2', '', ''],
    interp = 'linear,linear',
    spwmap = [tsysmap,[],[]],
    calwt = T,
    flagbackup = F)
  
  if applyonly != True: es.getCalWeightStats('uid___A002_X91a416_X3b2.ms') 
  

# Split out science SPWs and time average
mystep = 8
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf uid___A002_X91a416_X3b2.ms.split') 
  split(vis = 'uid___A002_X91a416_X3b2.ms',
    outputvis = 'uid___A002_X91a416_X3b2.ms.split',
    datacolumn = 'corrected',
    spw = '13,15,17,19',
    keepflags = T)
  
  

print "# Calibration"

# Listobs, clear pointing table, and save original flags
mystep = 9
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  fixvis('uid___A002_X91a416_X3b2.ms.split',field='J0431+2037',
         phasecenter='J2000 04h31m03.761375 20d37m34.2649s',
         datacolumn='DATA',reuse=False,
         outputvis='uid___A002_X91a416_X3b2.ms.split.fixed')

  os.system('rm -rf uid___A002_X91a416_X3b2.ms.split.fixed.listobs')
  listobs(vis = 'uid___A002_X91a416_X3b2.ms.split.fixed',
    listfile = 'uid___A002_X91a416_X3b2.ms.split.fixed.listobs')
  
  tb.open('uid___A002_X91a416_X3b2.ms.split.fixed/POINTING', nomodify = False)
  a = tb.rownumbers()
  tb.removerows(a)
  tb.close()
  
  if not os.path.exists('uid___A002_X91a416_X3b2.ms.split.fixed.flagversions/Original.flags'):
    flagmanager(vis = 'uid___A002_X91a416_X3b2.ms.split.fixed',
      mode = 'save',
      versionname = 'Original')
  
  

# Initial flagging
mystep = 10
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  # Flagging shadowed data
  
  flagdata(vis = 'uid___A002_X91a416_X3b2.ms.split.fixed',
    mode = 'shadow',
    flagbackup = F)
  
  # Flagging edge channels
  
  flagdata(vis = 'uid___A002_X91a416_X3b2.ms.split.fixed',
    mode = 'manual',
    spw = '0:0~7;120~127,1:0~7;120~127',
    flagbackup = F)

  # ICT-3835
  flagdata(vis = 'uid___A002_X91a416_X3b2.ms.split.fixed',
    mode = 'manual',
    timerange = '05:39:47~05:39:54',
    flagbackup = F)
  # This dataset does not show phase jumps on DVO1 spw=0, like the others do.  
  flagdata(vis = 'uid___A002_X91a416_X3b2.ms.split.fixed',
    mode = 'manual',
    antenna = 'DV06',  # low gain
    flagbackup = F)
#  flagdata(vis = 'uid___A002_X91a416_X3b2.ms.split.fixed',
#    mode = 'manual',  spw='0,1',
#    antenna = 'DA58,DA49',  # apparent low gain was due to delay error
#    flagbackup = F)
  

# Putting a model for the flux calibrator(s)
mystep = 11
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  setjy('uid___A002_X91a416_X3b2.ms.split.fixed',
            standard='manual', field='J0510+1800', spix=-0.483360,
            reffreq='108.188997GHz', fluxdensity=[1.331121,0,0,0])
"""
  setjy(vis = 'uid___A002_X91a416_X3b2.ms.split.fixed',
    field = '0', # source name = J0510+1800
    spw = '0', # center frequency of spw = 102.909325GHz
    standard = 'manual',
    fluxdensity = [1.41294287768, 0, 0, 0]) # frequency of measurement = 115.0GHz
  
  setjy(vis = 'uid___A002_X91a416_X3b2.ms.split.fixed',
    field = '0', # source name = J0510+1800
    spw = '1', # center frequency of spw = 101.1GHz
    standard = 'manual',
    fluxdensity = [1.41294287768, 0, 0, 0]) # frequency of measurement = 115.0GHz
  
  setjy(vis = 'uid___A002_X91a416_X3b2.ms.split.fixed',
    field = '0', # source name = J0510+1800
    spw = '2', # center frequency of spw = 115.255661182GHz
    standard = 'manual',
    fluxdensity = [1.41294287768, 0, 0, 0]) # frequency of measurement = 115.0GHz
  
  setjy(vis = 'uid___A002_X91a416_X3b2.ms.split.fixed',
    field = '0', # source name = J0510+1800
    spw = '3', # center frequency of spw = 113.491GHz
    standard = 'manual',
    fluxdensity = [1.41294287768, 0, 0, 0]) # frequency of measurement = 115.0GHz
"""  
  

# Save flags before bandpass cal
mystep = 12
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  
  flagmanager(vis = 'uid___A002_X91a416_X3b2.ms.split.fixed',
    mode = 'save',
    versionname = 'BeforeBandpassCalibration')
  
  

# Bandpass calibration
mystep = 13
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf uid___A002_X91a416_X3b2.ms.split.fixed.ap_pre_bandpass') 
  
  gaincal(vis = 'uid___A002_X91a416_X3b2.ms.split.fixed',
    caltable = 'uid___A002_X91a416_X3b2.ms.split.fixed.ap_pre_bandpass',
    field = '0', # J0510+1800
    spw = '0:51~76,1:51~76,2:1536~2304,3:1536~2304',
    solint = 'int',
    refant = 'DA51',
    calmode = 'p')
  
  if applyonly != True: es.checkCalTable('uid___A002_X91a416_X3b2.ms.split.fixed.ap_pre_bandpass', msName='uid___A002_X91a416_X3b2.ms.split.fixed', interactive=False) 
  
  os.system('rm -rf uid___A002_X91a416_X3b2.ms.split.fixed.bandpass') 
  bandpass(vis = 'uid___A002_X91a416_X3b2.ms.split.fixed',
    caltable = 'uid___A002_X91a416_X3b2.ms.split.fixed.bandpass',
    field = '0', # J0510+1800
    scan = '3',
    solint = 'inf,4MHz',
    combine = 'scan',
    refant = 'DA51',
    solnorm = True,
    bandtype = 'B',
    gaintable = 'uid___A002_X91a416_X3b2.ms.split.fixed.ap_pre_bandpass')
  
  if applyonly != True: es.checkCalTable('uid___A002_X91a416_X3b2.ms.split.fixed.bandpass', msName='uid___A002_X91a416_X3b2.ms.split.fixed', interactive=False) 
  

# Save flags before gain cal
mystep = 14
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  
  flagmanager(vis = 'uid___A002_X91a416_X3b2.ms.split.fixed',
    mode = 'save',
    versionname = 'BeforeGainCalibration')
  
  

# Gain calibration
mystep = 15
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf uid___A002_X91a416_X3b2.ms.split.fixed.phase_int') 
  gaincal(vis = 'uid___A002_X91a416_X3b2.ms.split.fixed',
    caltable = 'uid___A002_X91a416_X3b2.ms.split.fixed.phase_int',
    field = '0~1', # J0510+1800,J0431+2037
    solint = 'int',
    refant = 'DA51',
    gaintype = 'G',
    calmode = 'p',
    gaintable = 'uid___A002_X91a416_X3b2.ms.split.fixed.bandpass')
  
  if applyonly != True: es.checkCalTable('uid___A002_X91a416_X3b2.ms.split.fixed.phase_int', msName='uid___A002_X91a416_X3b2.ms.split.fixed', interactive=False) 
  
  os.system('rm -rf uid___A002_X91a416_X3b2.ms.split.fixed.ampli_inf') 
  gaincal(vis = 'uid___A002_X91a416_X3b2.ms.split.fixed',
    caltable = 'uid___A002_X91a416_X3b2.ms.split.fixed.ampli_inf',
    field = '0~1', # J0510+1800,J0431+2037
    solint = 'inf',
    refant = 'DA51',
    gaintype = 'T',
    calmode = 'a',
    gaintable = ['uid___A002_X91a416_X3b2.ms.split.fixed.bandpass', 'uid___A002_X91a416_X3b2.ms.split.fixed.phase_int'])
  
  if applyonly != True: es.checkCalTable('uid___A002_X91a416_X3b2.ms.split.fixed.ampli_inf', msName='uid___A002_X91a416_X3b2.ms.split.fixed', interactive=False) 
  
  os.system('rm -rf uid___A002_X91a416_X3b2.ms.split.fixed.flux_inf') 
  os.system('rm -rf uid___A002_X91a416_X3b2.ms.split.fixed.fluxscale') 
  mylogfile = casalog.logfile()
  casalog.setlogfile('uid___A002_X91a416_X3b2.ms.split.fixed.fluxscale')
  
  fluxscaleDict = fluxscale(vis = 'uid___A002_X91a416_X3b2.ms.split.fixed',
    caltable = 'uid___A002_X91a416_X3b2.ms.split.fixed.ampli_inf',
    fluxtable = 'uid___A002_X91a416_X3b2.ms.split.fixed.flux_inf',
    reference = '0') # J0510+1800
  
  casalog.setlogfile(mylogfile)
  
  if applyonly != True: es.fluxscale2(caltable = 'uid___A002_X91a416_X3b2.ms.split.fixed.ampli_inf', removeOutliers=True, msName='uid___A002_X91a416_X3b2.ms', writeToFile=True, preavg=10000)
  
  os.system('rm -rf uid___A002_X91a416_X3b2.ms.split.fixed.phase_inf') 
  gaincal(vis = 'uid___A002_X91a416_X3b2.ms.split.fixed',
    caltable = 'uid___A002_X91a416_X3b2.ms.split.fixed.phase_inf',
    field = '0~1', # J0510+1800,J0431+2037
    solint = 'inf',
    refant = 'DA51',
    gaintype = 'G',
    calmode = 'p',
    gaintable = 'uid___A002_X91a416_X3b2.ms.split.fixed.bandpass')
  
  if applyonly != True: es.checkCalTable('uid___A002_X91a416_X3b2.ms.split.fixed.phase_inf', msName='uid___A002_X91a416_X3b2.ms.split.fixed', interactive=False) 
  

# Save flags before applycal
mystep = 16
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  
  flagmanager(vis = 'uid___A002_X91a416_X3b2.ms.split.fixed',
    mode = 'save',
    versionname = 'BeforeApplycal')
  
  

# Application of the bandpass and gain cal tables
mystep = 17
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  for i in ['0']: # J0510+1800
    applycal(vis = 'uid___A002_X91a416_X3b2.ms.split.fixed',
      field = str(i),
      gaintable = ['uid___A002_X91a416_X3b2.ms.split.fixed.bandpass', 'uid___A002_X91a416_X3b2.ms.split.fixed.phase_int', 'uid___A002_X91a416_X3b2.ms.split.fixed.flux_inf'],
      gainfield = ['', i, i],
      interp = 'linear,linear',
      calwt = F,
      flagbackup = F)
  
  applycal(vis = 'uid___A002_X91a416_X3b2.ms.split.fixed',
    field = '1,2', # HL Tau
    gaintable = ['uid___A002_X91a416_X3b2.ms.split.fixed.bandpass', 'uid___A002_X91a416_X3b2.ms.split.fixed.phase_inf', 'uid___A002_X91a416_X3b2.ms.split.fixed.flux_inf'],
    gainfield = ['', '1', '1'], # J0431+2037
    interp = 'linear,linear',
    calwt = F,
    flagbackup = F)
  

# Split out corrected column
mystep = 18
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf uid___A002_X91a416_X3b2.ms.split.fixed.cal') 
  split(vis = 'uid___A002_X91a416_X3b2.ms.split.fixed',
    outputvis = 'uid___A002_X91a416_X3b2.ms.split.fixed.cal',
    datacolumn = 'corrected',
    keepflags = T)
  
  

  os.system('rm -rf HLTau_X3b2.ms.split.fixed.cal') 
  split(vis = 'uid___A002_X91a416_X3b2.ms.split.fixed',
    outputvis = 'HLTau_X3b2.ms.split.fixed.cal',
    datacolumn = 'corrected',field='2',
    keepflags = T)
